#!/bin/sh
# Marc Chappellier (c) STMicroElectronics 2006        
# Nicolas Chesne   (c) STMicroElectronics 2008

###############################################################################
##                SETUP STAPI DEVICE NAME ENVIRONMENT VARIABLES              ##
###############################################################################
if [ -z "$USE_UDEV" ]; then
 dev_root=""
 echo "USE_UDEV:$USE_UDEV"
else
 dev_root="/dev/.static"
 if [ -f ./skip_nodes ] ; then
  cp -a $dev_root/dev/stapi /dev/
  dev_root=""
  echo "skip_nodes"
 fi
fi
export dev_root
echo "dev_root:$dev_root"
# Verify if root module is specified
# ----------------------------------
export PATH=$PATH:/sbin
if [ -z "$MODULES_INSTALL_DIR" ] ; then
 export MODULES_INSTALL_DIR=/root/modules
fi
source $MODULES_INSTALL_DIR/load_env.sh
export PATH=$PATH:$MODULES_INSTALL_DIR

# Check if we are in 32 or 29bits
# -------------------------------
if [ -f $MODULES_INSTALL_DIR/load_modules_list_29BITS.txt ]; then
 LOAD_MODULES_LIST=$MODULES_INSTALL_DIR/load_modules_list_29BITS.txt
 MODE="29BITS"
else 
 MODE="32BITS"
 if [ -f $MODULES_INSTALL_DIR/load_modules_list_32BITS.txt ]; then
  LOAD_MODULES_LIST=$MODULES_INSTALL_DIR/load_modules_list_32BITS.txt
 else
  LOAD_MODULES_LIST=$MODULES_INSTALL_DIR/load_modules_list.txt
 fi
fi  

###############################################################################
##                          SETUP DIRECTORY ACCESS                           ##
###############################################################################

# Verify if modules list exist
# ----------------------------
if [ ! -f $LOAD_MODULES_LIST ] ; then
 echo "$LOAD_MODULES_LIST does not exist"
 exit
fi

# Create /dev/stapi directory if not exist
# ----------------------------------------
if [ ! -e $dev_root/dev/stapi ]; then mkdir -p $dev_root/dev/stapi ;fi
chmod 755 $dev_root/dev/stapi

###############################################################################
##                          MODULE INSERT PROCEDURE                          ##
###############################################################################


# Insert unique STAPI module
# --------------------------
 # We are first inserting stsys_ioctl because we need it to know the chip and cut
 echo "* Looking for chipset model and version..."
 insmod $MODULES_INSTALL_DIR/stos_core.ko
 insmod $MODULES_INSTALL_DIR/stsys_ioctl.ko
# Return chip version
# -------------------
 export chipset=`cat /proc/stsys_ioctl/chipset | cut -b1-7`
 export chipver=`cat /proc/stsys_ioctl/chipset | cut -b9-9`

 rmmod stsys_ioctl
 echo "  $chipset $chipver detected ($MODE)"

 # Now, we load video firmware
 echo "* Loading companions"
 insmod $MODULES_INSTALL_DIR/lxload.ko type=video1
if [ ! -f ./skip_nodes ] ; then
 create_node lxload
fi
 load_firmware "video1"
 insmod $MODULES_INSTALL_DIR/lxload.ko type=audio1
if [ ! -f ./skip_nodes ] ; then
 create_node lxload
fi
 load_firmware "audio1"
 rmmod stos_core

 # Now we load multicom
 echo "* Inserting Multicom"
 insmod $MODULES_INSTALL_DIR/embxshell.ko  || return 1
 insmod $MODULES_INSTALL_DIR/embxloopback.ko  || return 1 
 cat $LOAD_MODULES_LIST | grep "embxmailbox\.ko" | grep "$MODE" | while read mode mod_file node_name param; do
 insmod $MODULES_INSTALL_DIR/embxmailbox.ko "$param"; done
 cat $LOAD_MODULES_LIST | grep "embxshm\.ko"  | grep "$MODE"| while read mode mod_file node_name param; do
 insmod $MODULES_INSTALL_DIR/embxshm.ko "$param"; done
 cat $LOAD_MODULES_LIST | grep "mme_host\.ko" | while read mode mod_file node_name param; do
 insmod $MODULES_INSTALL_DIR/mme_host.ko "$param"; done

 # Now we load STAPI and create nodes
 echo "* Inserting STAPI Module"
 insmod $MODULES_INSTALL_DIR/stapi_core_stripped.ko || return 1
 if [ "$1" != "no_stapi_ioctl" ] ; then
  insmod $MODULES_INSTALL_DIR/stapi_ioctl_stripped.ko || return 1
 else
  insmod $MODULES_INSTALL_DIR/stpti4_ioctl.ko || return 1
 fi 

if [ ! -f ./skip_nodes ] ; then
 echo "* Creating device nodes in /dev/stapi"
 cat $LOAD_MODULES_LIST | grep -v "^#" | grep -v lxload | (while read mode mod_file node_name param; do
 if [ ! "$node_name" = "-" ] ; then
  create_node $node_name
 fi
 done)
 echo -n "" > ./skip_nodes
 cp -a $dev_root/dev/stapi /dev/
fi
echo " * Load modules OK * "

